@@ -28,83 +28,92 @@ function calculateScrollbarWidth() {
     cachedScrollbarWidth = (w1 - w2);
 }
 
-function reloadGraphs(max_image_width) {
-    $('a.replace-with-image').each(
-        function (index) {
-            var url, url_click, timestamp, width, height, amp_or_questionmark,
-            html_img, image, $main_tag, html_src, html_url, errormsg;
-            $main_tag = $(this);
-            width = $(this).parent('.img-use-my-size').innerWidth();
-            height = $(this).parent('.img-use-my-size').innerHeight();
-            if ($(this).attr('data-errormsg')) {
-                errormsg = $(this).attr('data-errormsg');
-            } else {
-                errormsg = 'An error occurred';
-            }
-            if (width === null) {
-                width = '';
-                height = '';
-            } else {
-                if (width > max_image_width) {
-                    width = max_image_width;
-                }
-                if (width < 10) {
-                    width = 0.5 * height;
-                }
-                if (height < 10) {
-                    height = 0.5 * width;
-                }
-                // Prevent a horizontal scrollbar in any case.
-                width = width - scrollbarWidth();
-            }
-            $(this).hide();
-            url = $(this).attr('href');
-            if (url.indexOf('?') === -1) {
-                amp_or_questionmark = '?';
-            } else {
-                amp_or_questionmark = '&';
-            }
-            url_click = $(this).attr('data-href-click');
-            // Remove a previous image that's already there.
-            // PROBABLY NOT NEEDED $('~ img', this).remove();
-            timestamp = new Date().getTime();  // No cached images.
-            html_url = url +
-                amp_or_questionmark + 'width=' + width +
-                '&height=' + height +
-                '&random=' + timestamp;
-            html_img = '<img src="' + html_url + '" class="auto-inserted" ' +
-                '/>';
-            // Remove progress animation and possibly old images.
-            $main_tag.parent().find(".auto-inserted").remove();
-
-            // Add progress animation.
-            $(this).after('<div class="auto-inserted"><img src="/static_media/lizard_ui/ajax-loader.gif" class="progress-animation" data-src="' + html_url + '" /></div>');
-
-            // Preload image.
-            image = $(html_img);
-
-            // Place <a href></a> around image tag.
-            if (url_click !== undefined) {
-                html_img = '<a href="' + url_click + '" class="auto-inserted">' + html_img + '</a>';
-            }
-
-            image.load(function () {
-                // After preloading.
-                // Remove progress animation and possibly old images.
-                $main_tag.parent().find(".auto-inserted").remove();
-                $main_tag.after(html_img);
-            });
-            image.error(function () {
-                // After preloading.
-                // Remove progress animation and possibly old images.
-                $main_tag.parent().find(".auto-inserted").remove();
-                $main_tag.after(
-                    '<p class="auto-inserted">' +
-                        errormsg +
-                        '</p>');
-            });
+function reloadGraph($graph, max_image_width) {
+    var url, url_click, timestamp, width, height, amp_or_questionmark,
+    html_img, image, $main_tag, html_src, html_url, errormsg;
+    $main_tag = $graph;
+    width = $graph.parent('.img-use-my-size').innerWidth();
+    height = $graph.parent('.img-use-my-size').innerHeight();
+    if ($graph.attr('data-errormsg')) {
+        errormsg = $graph.attr('data-errormsg');
+    } else {
+        errormsg = 'An error occurred';
+    }
+    if (width === null) {
+        width = '';
+        height = '';
+    } else {
+        if (width > max_image_width) {
+            width = max_image_width;
         }
-    );
+        if (width < 10) {
+            width = 0.5 * height;
+        }
+        if (height < 10) {
+            height = 0.5 * width;
+        }
+        // Prevent a horizontal scrollbar in any case.
+        width = width - scrollbarWidth();
+    }
+    $graph.hide();
+    url = $graph.attr('href');
+    if (url.indexOf('?') === -1) {
+        amp_or_questionmark = '?';
+    } else {
+        amp_or_questionmark = '&';
+    }
+    url_click = $graph.attr('data-href-click');
+    // Remove a previous image that's already there.
+    // PROBABLY NOT NEEDED $('~ img', this).remove();
+    timestamp = new Date().getTime();  // No cached images.
+    html_url = url +
+        amp_or_questionmark + 'width=' + width +
+        '&height=' + height +
+        '&random=' + timestamp;
+    html_img = '<img src="' + html_url + '" class="auto-inserted" ' +
+        '/>';
+    // Remove progress animation and possibly old images.
+    $main_tag.parent().find(".auto-inserted").remove();
+
+    // Add progress animation.
+    $graph.after('<div class="auto-inserted"><img src="/static_media/lizard_ui/ajax-loader.gif" class="progress-animation" data-src="' + html_url + '" /></div>');
+
+    // Preload image.
+    image = $(html_img);
+
+    // Place <a href></a> around image tag.
+    if (url_click !== undefined) {
+        html_img = '<a href="' + url_click + '" class="auto-inserted">' + html_img + '</a>';
+    }
+
+    image.load(function () {
+        // After preloading.
+        // Remove progress animation and possibly old images.
+        $main_tag.parent().find(".auto-inserted").remove();
+        $main_tag.after(html_img);
+    });
+    image.error(function () {
+        // After preloading.
+        // Remove progress animation and possibly old images.
+        $main_tag.parent().find(".auto-inserted").remove();
+        $main_tag.after(
+            '<p class="auto-inserted">' +
+                errormsg +
+                '</p>');
+    });
+}
+
+function reloadGraphs(max_image_width) {
+    $('a.replace-with-image').each(function () {
+        reloadGraph($(this), max_image_width);
+    });
+}
+
+
+function reloadLocalizedGraphs($location, max_image_width) {
+    $('a.replace-with-image', $location).each(function () {
+        reloadGraph($(this, max_image_width));
+    });
 }
 
 
@@ -501,6 +510,32 @@ $(document).ready(function () {
     setUpLogin();
     setUpPrintButton();
 
+    // Initialize Tipsy
+    $('a[rel=tipsy]').tipsy({
+        delayIn: 200,
+        delayOut: 200,
+        fade: false,
+        gravity: 'w'
+    });
+    $('a#logo-img').tipsy({
+        delayIn: 200,
+        delayOut: 200,
+        fade: false,
+        gravity: 'n'
+    });
+    $('span[rel=tipsy]').tipsy({
+        delayIn: 200,
+        delayOut: 200,
+        fade: false,
+        gravity: 's'
+    });
+    $('#summary-datepicker-a').tipsy({
+        delayIn: 200,
+        delayOut: 200,
+        fade: false,
+        gravity: 's'
+    });
+
     //setUpWorkspaceAcceptableButtons();
     // Light up the selected tab, if available.
     setUpPortalTabs();
